=======
Credits
=======

Development Lead
----------------

* Emma Caizergues <emma.caizergues@gmail.com>

Contributors
------------

* François Durand <fradurand@gmail.com>
* Fabien Mathieu <fabien.mathieu@normalesup.org>
